translate.search.indexing.CommonIndexer

Package translate :: Package search :: Package indexing :: Module CommonIndexer |
[hide private]
[frames] | no frames]

# Module CommonIndexer

source code

base class for interfaces to indexing engines for pootle

Classes | [hide private]
| CommonDatabase base class for indexing support
| CommonEnquire an enquire object contains the information about the result of a request

Functions | [hide private]
bool |
is_available() check if this indexing engine interface is usable | source code

Variables | [hide private]
| __revision__ = ``'``$Id: CommonIndexer.py 8507 2008-09-27 09:15:08``...``

Imports: translate, os

Function Details | [hide private]

### is_available() | source code
check if this indexing engine interface is usable this function must exist in every module that contains indexing engine interfaces Returns: bool is this interface usable?

Variables Details | [hide private]

  ### __revision__ Value:
      '$Id: CommonIndexer.py 8507 2008-09-27 09:15:08Z dwaynebailey $'